@@ -1,7 +1,8 @@
 pub mod completions;
-// pub mod config;
 pub mod configure;
 pub mod connect;
 pub mod default;
 pub mod list;
+pub mod login;
+pub mod logout;
 pub mod profile;
